==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/DeliveryRuleRemoteAddressConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Defines the RemoteAddress condition for the delivery rule.
 * @property name The name of the condition for the delivery rule.
 * Expected value is 'RemoteAddress'.
 * @property parameters Defines the parameters for the condition.
 */
public data class DeliveryRuleRemoteAddressConditionArgs(
    public val name: Output<String>,
    public val parameters: Output<RemoteAddressMatchConditionParametersArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs =
        com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .parameters(parameters.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DeliveryRuleRemoteAddressConditionArgs].
 */
@PulumiTagMarker
public class DeliveryRuleRemoteAddressConditionArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var parameters: Output<RemoteAddressMatchConditionParametersArgs>? = null

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'RemoteAddress'.
     */
    @JvmName("tdesgarkjpxblqyv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("ovqjjaoeobntnkep")
    public suspend fun parameters(`value`: Output<RemoteAddressMatchConditionParametersArgs>) {
        this.parameters = value
    }

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'RemoteAddress'.
     */
    @JvmName("nsudsnkhgfnoootm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("xhvgwioihvxtgfdd")
    public suspend fun parameters(`value`: RemoteAddressMatchConditionParametersArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Defines the parameters for the condition.
     */
    @JvmName("cplbordixbidydkw")
    public suspend
    fun parameters(argument: suspend RemoteAddressMatchConditionParametersArgsBuilder.() -> Unit) {
        val toBeMapped = RemoteAddressMatchConditionParametersArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    internal fun build(): DeliveryRuleRemoteAddressConditionArgs =
        DeliveryRuleRemoteAddressConditionArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            parameters = parameters ?: throw PulumiNullFieldException("parameters"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/DeliveryRuleRemoteAddressConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Defines the RemoteAddress condition for the delivery rule.
 * @property name The name of the condition for the delivery rule.
 * Expected value is 'RemoteAddress'.
 * @property parameters Defines the parameters for the condition.
 */
public data class DeliveryRuleRemoteAddressConditionArgs(
    public val name: Output<String>,
    public val parameters: Output<RemoteAddressMatchConditionParametersArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs =
        com.pulumi.azurenative.cdn.inputs.DeliveryRuleRemoteAddressConditionArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .parameters(parameters.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DeliveryRuleRemoteAddressConditionArgs].
 */
@PulumiTagMarker
public class DeliveryRuleRemoteAddressConditionArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var parameters: Output<RemoteAddressMatchConditionParametersArgs>? = null

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'RemoteAddress'.
     */
    @JvmName("rtbyctikgrpduxde")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("wcxchdeyqkdfwene")
    public suspend fun parameters(`value`: Output<RemoteAddressMatchConditionParametersArgs>) {
        this.parameters = value
    }

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'RemoteAddress'.
     */
    @JvmName("qijdhodxlcnyrmoa")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("ulscurkmaqidjjrc")
    public suspend fun parameters(`value`: RemoteAddressMatchConditionParametersArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Defines the parameters for the condition.
     */
    @JvmName("ambssmuvvnweuusc")
    public suspend
    fun parameters(argument: suspend RemoteAddressMatchConditionParametersArgsBuilder.() -> Unit) {
        val toBeMapped = RemoteAddressMatchConditionParametersArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    internal fun build(): DeliveryRuleRemoteAddressConditionArgs =
        DeliveryRuleRemoteAddressConditionArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            parameters = parameters ?: throw PulumiNullFieldException("parameters"),
        )
}
